/**********************************************************************
Copyright (c) 2008 Erik Bengtson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors :
2008 Andy Jefferson - abstracted methods up to AbstractStoreManager
 ...
***********************************************************************/
package org.datanucleus.store.ldap;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import org.datanucleus.ClassLoaderResolver;
import org.datanucleus.OMFContext;
import org.datanucleus.metadata.MetaDataListener;
import org.datanucleus.store.AbstractStoreManager;

/**
 * Manager for LDAP datastores.
 */
public class LDAPStoreManager extends AbstractStoreManager
{
    MetaDataListener metadataListener;

    /**
     * Constructor.
     * @param clr ClassLoader resolver
     * @param omfContext ObjectManagerFactory context
     */
    public LDAPStoreManager(ClassLoaderResolver clr, OMFContext omfContext)
    {
        super("ldap", clr, omfContext);

        // Handler for metadata
        metadataListener = new LDAPMetaDataListener();
        omfContext.getMetaDataManager().registerListener(metadataListener);

        // Handler for persistence process
        persistenceHandler2 = new LDAPPersistenceHandler(this);

        logConfiguration();
    }

    /**
     * Release of resources
     */
    public void close()
    {
        omfContext.getMetaDataManager().deregisterListener(metadataListener);
        super.close();
    }

    /**
     * Accessor for the supported options in string form.
     * @return Supported options
     */
    public Collection getSupportedOptions()
    {
        Set set = new HashSet();
        set.add("ApplicationIdentity");
        set.add("TransactionIsolationLevel.read-committed");
        set.add("ORM");
        return set;
    }
}